@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-c329238e8025cd02b1a2244c3dbf7a4a
-key: yesod_GSS6djoSbbGLPFgfaGKpCD
+id: yesod-1.4.2-8436fd4d102761883846218f9f68fdc1
+key: yesod_E8E3Tjai3TIAloYzzdGbir
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-GSS6djoSbbGLPFgfaGKpCD
+hs-libraries: HSyesod-1.4.2-E8E3Tjai3TIAloYzzdGbir
 depends:
     aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -48,9 +48,9 @@ depends:
     wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
     warp-3.2.3-0fe962c9e43b4ce1b68b117c1dfdd0a0
     yaml-0.8.16-8e3a1d884bd629b7e4f9063e0e319626
-    yesod-auth-1.4.12-6d39f9c8689d7bb14181c06ad864efcd
+    yesod-auth-1.4.12-7a529577a804cb551b6b7d6c47902df1
     yesod-core-1.4.19-af1bfc6a6dd9bd0b41ee49e8528d9426
-    yesod-form-1.4.6-d410f0f26d14c25fe71f8e61bc7bca41
+    yesod-form-1.4.6-415153f28e1893b4512dcf5801e9d2dc
     yesod-persistent-1.4.0.3-c0d4792363b4ae6f164db4f0ba0d02bd
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
